================================================
Mailman - The GNU Mailing List Management System
================================================

Copyright (C) 1998-2012 by the Free Software Foundation, Inc.

This is GNU Mailman, a mailing list management system distributed under the
terms of the GNU General Public License (GPL) version 3 or later.  The name of
this software is spelled "Mailman" with a leading capital 'M' but with a lower
case second 'm'.  Any other spelling is incorrect.

Mailman is written in Python which is available for all platforms that Mailman
is supported on, including GNU/Linux and most other Unix-like operating
systems (e.g. Solaris, \*BSD, MacOSX, etc.).  Mailman is not supported on
Windows, although web and mail clients on any platform should be able to
interact with Mailman just fine.

The Mailman home page is:

    http://www.list.org

and there is a community driven wiki at

    http://wiki.list.org

For more information on Mailman, see the above web sites, or the documentation
provided with this software.  Start at src/mailman/docs/README.txt.


Table of Contents
=================

.. toctree::
    :glob:

    src/mailman/docs/INTRODUCTION
    src/mailman/docs/START
    src/mailman/docs/DATABASE
    src/mailman/docs/MTA
    src/mailman/docs/8-miles-high
    src/mailman/bin/docs/*
    src/mailman/commands/docs/*
    src/mailman/database/docs/*
    src/mailman/model/docs/*
    src/mailman/core/docs/*
    src/mailman/app/docs/*
    src/mailman/styles/docs/*
    src/mailman/runners/docs/*
    src/mailman/handlers/docs/*
    src/mailman/rest/docs/*
    src/mailman/chains/docs/*
    src/mailman/rules/docs/*
    src/mailman/archiving/docs/*
    src/mailman/mta/docs/*
    src/mailman/docs/NEWS
    src/mailman/docs/STYLEGUIDE
    src/mailman/docs/ACKNOWLEDGMENTS


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
